/**
 * tiny event emitter
 * modify from mitt
 */
import type { CreateFrom, ERROR, EventType } from '../types';
import type Highlighter from '../index';
import type HighlightSource from '../model/source';
interface EventHandlerMap {
    [key: string]: (...args: any[]) => void;
    [EventType.CLICK]: (data: {
        id: string;
    }, h: Highlighter, e: MouseEvent | TouchEvent) => void;
    [EventType.HOVER]: (data: {
        id: string;
    }, h: Highlighter, e: MouseEvent | TouchEvent) => void;
    [EventType.HOVER_OUT]: (data: {
        id: string;
    }, h: Highlighter, e: MouseEvent | TouchEvent) => void;
    [EventType.CREATE]: (data: {
        sources: HighlightSource[];
        type: CreateFrom;
    }, h: Highlighter) => void;
    [EventType.REMOVE]: (data: {
        ids: string[];
    }, h: Highlighter) => void;
    error: (data: {
        type: ERROR;
        detail?: HighlightSource;
        error?: any;
    }) => void;
}
declare class EventEmitter {
    private handlersMap;
    on<T extends keyof EventHandlerMap>(type: T, handler: EventHandlerMap[T]): this;
    off<T extends keyof EventHandlerMap>(type: T, handler: EventHandlerMap[T]): this;
    emit<T extends keyof EventHandlerMap>(type: T, ...data: Parameters<EventHandlerMap[T]>): this;
}
export default EventEmitter;
